=======
Credits
=======

Development Lead
----------------

* Travis Logan <logan.travis@ouranos.ca> `@tlogan2000 <https://github.com/tlogan2000>`_

Co-Developers
-------------

* Sébastien Biner <biner.sebastien@ouranos.ca> `@sbiner <https://github.com/sbiner>`_
* David Huard <huard.david@ouranos.ca> `@huard <https://github.com/huard>`_
* Philippe Roy <roy.philippe@ouranos.ca> `@Balinus <https://github.com/Balinus>`_
* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_

Contributors
------------

* David Caron `@davidcaron <https://github.com/davidcaron>`_
* Jwen Fai Low `@jwenfai <https://github.com/jwenfai>`_
